@@ -11,29 +11,13 @@ use URI;
 use String::ShellQuote;
 
 my $app = 'eg/dot-psgi/Hello.psgi';
-my $ab  = 'ab -t 1 -c 10 -k';
+my $ab  = 'ab -n 100 -c 10 -k';
 my $url = 'http://127.0.0.1/';
 
-my @try = (
-    [ 'AnyEvent::HTTPD' ],
-    [ 'HTTP::Server::PSGI' ],
-    [ 'Twiggy' ],
-    [ 'HTTP::Server::Simple' ],
-    [ 'Corona' ],
-    [ 'Danga::Socket' ],
-    [ '+POE::Component::Server::PSGI' ],
-    [ 'Starman', ' (workers=10)', workers => 10 ],
-    [ 'Starlet', ' (workers=10)', max_workers => 10 ],
-);
+my @backends = grep eval "require Plack::Server::$_; 1",
+    qw( AnyEvent Standalone Standalone::Prefork ServerSimple Coro Danga::Socket );
 
-my @backends;
-
-for my $handler (@try) {
-    eval { Plack::Loader->load($handler->[0]) };
-    push @backends, $handler unless $@;
-}
-
-warn "Testing implementations: ", join(", ", map $_->[0], @backends), "\n";
+warn "Testing implementations: ", join(", ", @backends), "\n";
 
 GetOptions(
     'a|app=s'   => \$app,
@@ -50,14 +34,14 @@ ab:  $ab
 URL: $url
 
 EOF
-    for my $handler (@backends) {
-        run_one(@$handler);
+    for my $server_class (@backends) {
+        run_one($server_class);
     }
 }
 
 sub run_one {
-    my($server_class, $how, @args) = @_;
-    print "-- server: $server_class ", ($how || ''), "\n";
+    my $server_class = shift;
+    print "-- server: $server_class\n";
 
     test_tcp(
         client => sub {
@@ -65,13 +49,12 @@ sub run_one {
             my $uri = URI->new($url);
             $uri->port($port);
             $uri = shell_quote($uri);
-            system "ab -n 20 $uri > /dev/null"; # warmup
             print `$ab $uri | grep 'Requests per '`;
         },
         server => sub {
             my $port = shift;
             my $handler = Plack::Util::load_psgi $app;
-            my $server = Plack::Loader->load($server_class, port => $port, @args);
+            my $server = Plack::Loader->load($server_class, port => $port);
             $server->run($handler);
         },
     );
